==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/mixer/adapter/prometheus/MetricInfoFluent.java <==
package me.snowdrop.istio.mixer.adapter.prometheus;

import javax.validation.constraints.Pattern;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonProperty;
import javax.validation.constraints.Size;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public interface MetricInfoFluent<A extends me.snowdrop.istio.mixer.adapter.prometheus.MetricInfoFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBuckets instead.
 * @return The buildable object.
 */
@Deprecated public BucketsDefinition getBuckets();
    public BucketsDefinition buildBuckets();
    public A withBuckets(BucketsDefinition buckets);
    public Boolean hasBuckets();
    public MetricInfoFluent.BucketsNested<A> withNewBuckets();
    public MetricInfoFluent.BucketsNested<A> withNewBucketsLike(BucketsDefinition item);
    public MetricInfoFluent.BucketsNested<A> editBuckets();
    public MetricInfoFluent.BucketsNested<A> editOrNewBuckets();
    public MetricInfoFluent.BucketsNested<A> editOrNewBucketsLike(BucketsDefinition item);
    public String getDescription();
    public A withDescription(String description);
    public Boolean hasDescription();
    public String getInstanceName();
    public A withInstanceName(String instanceName);
    public Boolean hasInstanceName();
    public Kind getKind();
    public A withKind(Kind kind);
    public Boolean hasKind();
    public A addToLabelNames(int index,String item);
    public A setToLabelNames(int index,String item);
    public A addToLabelNames(String... items);
    public A addAllToLabelNames(Collection<String> items);
    public A removeFromLabelNames(String... items);
    public A removeAllFromLabelNames(Collection<String> items);
    public List<String> getLabelNames();
    public String getLabelName(int index);
    public String getFirstLabelName();
    public String getLastLabelName();
    public String getMatchingLabelName(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withLabelNames(List<String> labelNames);
    public A withLabelNames(String... labelNames);
    public Boolean hasLabelNames();
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public String getNamespace();
    public A withNamespace(String namespace);
    public Boolean hasNamespace();

    public interface BucketsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BucketsDefinitionFluent<MetricInfoFluent.BucketsNested<N>>{

        
    public N and();    public N endBuckets();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/prometheus/MetricInfoFluent.java <==
package me.snowdrop.istio.mixer.adapter.prometheus;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public interface MetricInfoFluent<A extends me.snowdrop.istio.mixer.adapter.prometheus.MetricInfoFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBuckets instead.
 * @return The buildable object.
 */
@Deprecated public BucketsDefinition getBuckets();
    public BucketsDefinition buildBuckets();
    public A withBuckets(BucketsDefinition buckets);
    public Boolean hasBuckets();
    public MetricInfoFluent.BucketsNested<A> withNewBuckets();
    public MetricInfoFluent.BucketsNested<A> withNewBucketsLike(BucketsDefinition item);
    public MetricInfoFluent.BucketsNested<A> editBuckets();
    public MetricInfoFluent.BucketsNested<A> editOrNewBuckets();
    public MetricInfoFluent.BucketsNested<A> editOrNewBucketsLike(BucketsDefinition item);
    public String getDescription();
    public A withDescription(String description);
    public Boolean hasDescription();
    public A withNewDescription(String arg1);
    public A withNewDescription(StringBuilder arg1);
    public A withNewDescription(StringBuffer arg1);
    public String getInstanceName();
    public A withInstanceName(String instanceName);
    public Boolean hasInstanceName();
    public A withNewInstanceName(String arg1);
    public A withNewInstanceName(StringBuilder arg1);
    public A withNewInstanceName(StringBuffer arg1);
    public Kind getKind();
    public A withKind(Kind kind);
    public Boolean hasKind();
    public A addToLabelNames(int index,String item);
    public A setToLabelNames(int index,String item);
    public A addToLabelNames(String... items);
    public A addAllToLabelNames(Collection<String> items);
    public A removeFromLabelNames(String... items);
    public A removeAllFromLabelNames(Collection<String> items);
    public List<String> getLabelNames();
    public String getLabelName(int index);
    public String getFirstLabelName();
    public String getLastLabelName();
    public String getMatchingLabelName(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingLabelName(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withLabelNames(List<String> labelNames);
    public A withLabelNames(String... labelNames);
    public Boolean hasLabelNames();
    public A addNewLabelName(String arg1);
    public A addNewLabelName(StringBuilder arg1);
    public A addNewLabelName(StringBuffer arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    public String getNamespace();
    public A withNamespace(String namespace);
    public Boolean hasNamespace();
    public A withNewNamespace(String arg1);
    public A withNewNamespace(StringBuilder arg1);
    public A withNewNamespace(StringBuffer arg1);

    public interface BucketsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BucketsDefinitionFluent<MetricInfoFluent.BucketsNested<N>>{

        
    public N and();    public N endBuckets();
}


}
